@@ -11,7 +11,7 @@
 #'            }
 #'
 #' @param path File path to the data file.
-#' @param enc File encoding of the SPSS dataset. \emph{Not needed if \code{option = "haven"} (default).}
+#' @param enc File encoding of the data file. See 'Details'.
 #' @param attach.var.labels Logical, if \code{TRUE}, variable labels will automatically be
 #'          added to each variable as \code{"variable.label"} attribute. Use this
 #'          parameter, if \code{option = "foreign"}, where variable labels are added
@@ -49,6 +49,11 @@
 #'         used with other functions like \code{\link{barplot}} etc.
 #'         See 'Examples' from \code{\link{get_labels}}.
 #'
+#' @details In some cases, column names of the imported data set are not properly
+#'            encoded. Use the \code{enc}-argument to specify the character
+#'            encoding for the SPSS data set (like \code{enc = "UTF-8"}, see
+#'            \code{\link{Encoding}}).
+#'
 #' @examples
 #' \dontrun{
 #' # import SPSS data set. uses haven's read function
@@ -77,9 +82,8 @@ read_spss <- function(path,
                       atomic.to.fac = FALSE,
                       keep.na = FALSE,
                       option = "haven") {
-  # --------------------------------------------------------
+
   # check read_spss option
-  # --------------------------------------------------------
   if (is.null(option)) {
     opt <- getOption("read_spss")
     if (is.null(opt) || opt == "foreign") {
@@ -88,20 +92,16 @@ read_spss <- function(path,
       option <- "haven"
     }
   }
-  # -------------------------------------
+
   # check parameter
-  # -------------------------------------
   if (!is.null(option) && option != "foreign" && option != "haven") {
-    warning("'option' must be either 'foreign' or 'haven'. Defaulting to 'foreign'.", call. = F)
+    warning("`option` must be either `foreign` or `haven`. Defaulting to `foreign`.", call. = F)
     option <- "foreign"
   }
-  # -------------------------------------
+
   # foreign import
-  # -------------------------------------
   if (option == "foreign") {
-    # ------------------------
     # check if suggested package is available
-    # ------------------------
     if (!requireNamespace("foreign", quietly = TRUE)) {
       stop("Package 'foreign' needed for this function to work. Please install it.", call. = FALSE)
     }
@@ -119,14 +119,14 @@ read_spss <- function(path,
       data.spss <- set_label(data.spss, get_label(data.spss))
     }
   } else {
-    # ------------------------
     # check if suggested package is available
-    # ------------------------
     if (!requireNamespace("haven", quietly = TRUE)) {
       stop("Package 'haven' needed for this function to work. Please install it.", call. = FALSE)
     }
     # read data file
     data.spss <- haven::read_spss(path)
+    # encoding?
+    if (!is.na(enc) && !is.null(enc)) Encoding(colnames(data.spss)) <- enc
     # convert NA
     if (!keep.na) data.spss <- to_na(data.spss)
     # convert to sjPlot
@@ -145,9 +145,7 @@ read_spss <- function(path,
 atomic_to_fac <- function(data.spss, attr.string) {
   # check for valid attr.string
   if (!is.null(attr.string)) {
-    # -------------------------------------
     # create progress bar
-    # -------------------------------------
     pb <- utils::txtProgressBar(min = 0,
                                 max = ncol(data.spss),
                                 style = 3)
@@ -202,9 +200,7 @@ atomic_to_fac <- function(data.spss, attr.string) {
 #' @importFrom haven read_sas
 #' @export
 read_sas <- function(path, path.cat = NULL, atomic.to.fac = FALSE) {
-  # ------------------------
   # check if suggested package is available
-  # ------------------------
   if (!requireNamespace("haven", quietly = TRUE)) {
     stop("Package 'haven' needed for this function to work. Please install it.", call. = FALSE)
   }
@@ -239,9 +235,7 @@ read_sas <- function(path, path.cat = NULL, atomic.to.fac = FALSE) {
 #' @importFrom haven read_dta
 #' @export
 read_stata <- function(path, atomic.to.fac = FALSE) {
-  # ------------------------
   # check if suggested package is available
-  # ------------------------
   if (!requireNamespace("haven", quietly = TRUE)) {
     stop("Package 'haven' needed for this function to work. Please install it.", call. = FALSE)
   }
@@ -308,15 +302,12 @@ write_stata <- function(x, path, enc.to.utf8 = TRUE) {
 #' @importFrom haven write_sav write_dta
 #' @importFrom utils txtProgressBar setTxtProgressBar
 write_data <- function(x, path, type, enc.to.utf8) {
-  # ------------------------
   # check if suggested package is available
-  # ------------------------
   if (!requireNamespace("haven", quietly = TRUE)) {
     stop("Package 'haven' needed for this function to work. Please install it.", call. = FALSE)
   }
-  # -------------------------------------
+
   # create progress bar
-  # -------------------------------------
   pb <- utils::txtProgressBar(min = 0,
                               max = ncol(x),
                               style = 3)
