@@ -14,7 +14,9 @@
 #'          to create in output. Must be of same length as number of column
 #'          groups that should be gathered. See 'Examples'.
 #' @param ... Specification of columns that should be gathered. Must be one
-#'          character vector with variable names per column group.
+#'          character vector with variable names per column group, or a numeric
+#'          vector with column indices indicating those columns that should be
+#'          gathered. See 'Examples'.
 #' @param labels Character vector of same length as \code{values} with variable
 #'          labels for the new variables created from gathered columns.
 #'          See 'Examples' and 'Details'.
@@ -56,6 +58,12 @@
 #'         c("speed_t1", "speed_t2", "speed_t3"),
 #'         recode.key = TRUE)
 #'
+#' # gather multiple columns by colum names and colum indices
+#' to_long(mydat, "time", c("score", "speed"),
+#'         c("score_t1", "score_t2", "score_t3"),
+#'         c(6:8),
+#'         recode.key = TRUE)
+#'
 #' # gather multiple columns, use separate key-column for each value-vector
 #' to_long(mydat, c("time_score", "time_speed"), c("score", "speed"),
 #'         c("score_t1", "score_t2", "score_t3"),
@@ -91,6 +99,14 @@ to_long <- function(data, keys, values, ..., labels = NULL, recode.key = FALSE)
     warning("`labels` must be of same length as `values`. Dropping variable labels for gathered columns.")
     labels <- NULL
   }
+  # check for numeric indices, and get column names then
+  for (i in length(data_cols)) {
+    # check if all values are numeric
+    if (all(is.numeric(data_cols[[i]]))) {
+      # get column names instead
+      data_cols[[i]] <- colnames(data)[data_cols[[i]]]
+    }
+  }
   # get all columns that should be gathered
   all_data_cols <- unlist(data_cols)
   # iterate each column group
@@ -101,20 +117,15 @@ to_long <- function(data, keys, values, ..., labels = NULL, recode.key = FALSE)
     # remove those columns that should not be gathered
     tmp <- data[, -match(remove_cols, colnames(data))]
     # gather data frame
-     tmp <- suppressWarnings(
-       tidyr::gather_(tmp,
-                      keys[i],
-                      values[i],
-                      data_cols[[i]])
-       )
-     # need to recode key-value?
-     if (recode.key)
-       tmp[[keys[i]]] <- to_value(tmp[[keys[i]]], keep.labels = FALSE)
-     # set variable label
-     if (!is.null(labels))
-       set_label(tmp[[values[i]]]) <- labels[i]
-     # add output to list
-     dummy[[length(dummy) + 1]] <- tmp
+    tmp <- suppressWarnings(tidyr::gather_(tmp, keys[i], values[i], data_cols[[i]]))
+    # need to recode key-value?
+    if (recode.key)
+      tmp[[keys[i]]] <- sort(to_value(tmp[[keys[i]]], keep.labels = FALSE))
+    # set variable label
+    if (!is.null(labels))
+      set_label(tmp[[values[i]]]) <- labels[i]
+    # add output to list
+    dummy[[length(dummy) + 1]] <- tmp
   }
   # we have at least one gathered data frame
   mydat <- dummy[[1]]
